**Example 1: 清除强代付关系**

清除合作伙伴和客户的强代付关系

Input: 

```
tccli partners RemovePayRelationForClient --cli-unfold-argument  \
    --ClientUin 123
```

Output: 
```
{
    "Response": {
        "RequestId": "5da478d6-abf4-47a3-80a6-6660d170eee3"
    }
}
```

